#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'bee'

from django.conf.urls import include, url
from . import views

app_name = 'bee_django_report'
urlpatterns = [
    url(r'^test$', views.test, name='test'),
    url(r'^$', views.IndexView.as_view(), name='index'),

    url(r'^user/gender/$', views.UserGenderView.as_view(), name='user_gender'),
    url(r'^user/age/$', views.UserAgeView.as_view(), name='user_age'),
    # 学生列表，统计学习进度
    url(r'^user/section/$', views.UserSectionList.as_view(), name='user_section'),
    # 助教评分
    url(r'^mentor/score/list/(?P<user_id>[0-9]+)/$', views.MentorScoreList.as_view(), name='mentor_score_list'),
    url(r'^mentor/score/detail/(?P<pk>[0-9]+)/$', views.MentorScoreDetail.as_view(), name='mentor_score_detail'),
    url(r'^mentor/score/add/(?P<user_id>[0-9]+)/$', views.MentorScoreCreate.as_view(), name='mentor_score_add'),
    url(r'^mentor/score/update/(?P<pk>[0-9]+)/$', views.MentorScoreUpdate.as_view(), name='mentor_score_update'),
    url(r'^mentor/score/update/score/(?P<pk>[0-9]+)/$', views.MentorScoreUpdateScore.as_view(), name='mentor_score_update_score'),
    url(r'^mentor/score/delete/(?P<pk>[0-9]+)/$', views.MentorScoreDelete.as_view(), name='mentor_score_delete'),
    #     班级学习进度
    url('^user_class/progress/(?P<class_id>\d+)/$', views.UserClassProgress.as_view(), name='user_class_progress'),
    # 班级周报表
    url(r'^class/week/(?P<class_id>[0-9]+)/$', views.ClassWeekView.as_view(), name='class_week'),
    # 客服，管理的助教
    url(r'^server/assistant/$', views.ServerAssistantView.as_view(), name='server_assistant'),
    # 总览
    url(r'^dashboard$', views.DashboardView.as_view(), name='dashboard'),

]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-25 08:21
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_report', '0008_auto_20191025_1640'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='report',
            options={'permissions': (('can_view_report', '\u53ef\u4ee5\u67e5\u770b\u62a5\u8868'), ('can_view_website_report', 'can_view_website_report'), ('can_view_user_report', 'can_view_user_report'), ('can_view_course_report', 'can_view_course_report'))},
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-30 06:13
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_report', '0004_auto_20190711_1718'),
    ]

    operations = [
        migrations.AddField(
            model_name='classweek',
            name='live_commented_count',
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name='classweek',
            name='live_watched_count',
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name='classweek',
            name='live_watched_days',
            field=models.IntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='classweek',
            name='feed_count',
            field=models.IntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='classweek',
            name='live_count',
            field=models.IntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='classweek',
            name='live_days',
            field=models.IntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='classweek',
            name='live_mins',
            field=models.IntegerField(default=0),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-10-25 08:40
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_report', '0007_auto_20191025_1453'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='mentorscoreweek',
            options={'ordering': ['created_at'], 'permissions': (('view_mentorscoreweek', '\u53ef\u4ee5\u67e5\u770b\u5168\u90e8\u52a9\u6559\u5206\u6570'), ('change_score1', '\u53ef\u4ee5\u4fee\u6539\u5206\u65701'), ('change_score2', '\u53ef\u4ee5\u4fee\u6539\u5206\u65702'), ('change_score3', '\u53ef\u4ee5\u4fee\u6539\u5206\u65703'), ('change_score4', '\u53ef\u4ee5\u4fee\u6539\u5206\u65704'))},
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-10-25 06:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_report', '0006_auto_20190927_1449'),
    ]

    operations = [
        migrations.AddField(
            model_name='mentorscoreweek',
            name='score1',
            field=models.FloatField(blank=True, null=True, verbose_name='\u5206\u65701'),
        ),
        migrations.AddField(
            model_name='mentorscoreweek',
            name='score2',
            field=models.FloatField(blank=True, null=True, verbose_name='\u5206\u65702'),
        ),
        migrations.AddField(
            model_name='mentorscoreweek',
            name='score3',
            field=models.FloatField(blank=True, null=True, verbose_name='\u5206\u65703'),
        ),
        migrations.AddField(
            model_name='mentorscoreweek',
            name='score4',
            field=models.FloatField(blank=True, null=True, verbose_name='\u5206\u65704'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-09-27 06:49
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_report', '0005_auto_20190830_1413'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='mentorscoreweek',
            options={'ordering': ['created_at'], 'permissions': (('view_mentorscoreweek', '\u53ef\u4ee5\u67e5\u770b\u5168\u90e8\u52a9\u6559\u5206\u6570'),)},
        ),
        migrations.AlterModelOptions(
            name='report',
            options={'permissions': (('can_view_report', '\u53ef\u4ee5\u67e5\u770b\u62a5\u8868'),)},
        ),
    ]



# -*- coding:utf-8 -*-
__author__ = 'bee'

from django import forms

from .models import MentorScoreWeek, Report


class MentorScoreWeekForm(forms.ModelForm):
    class Meta:
        model = MentorScoreWeek
        fields = ['year', "week", "info"]

    # def update_rank(self):


class MentorScoreWeekUpdateScoreForm(forms.ModelForm):
    class Meta:
        model = MentorScoreWeek
        fields = []
        fieldsets = [(u'aa', {"fields": ["score1", "score2"]})]

    def __init__(self, request_user, *args, **kwargs):
        super(MentorScoreWeekUpdateScoreForm, self).__init__(*args, **kwargs)
        _list = MentorScoreWeek.get_score_title_list(request_user)
        # score1, score2, score3, score4 = None, None, None, None
        for _dict in _list:
            if not _dict["can_change"]:
                _widget = forms.TextInput(attrs={'disabled': 'disabled'})
            else:
                _widget = None
            key = _dict["key"]
            self.fields[key] = forms.FloatField(label=_dict["name"], required=False, help_text=_dict["help_text"],
                                                widget=_widget)
            self.initial[key] = kwargs["instance"].__dict__[key]
            # if f["can_change"]:
            #     score2 = forms.FloatField(label=f["name"], required=False)
            # if f["can_change"]:
            #     score3 = forms.FloatField(label=f["name"], required=False)
            # if f["can_change"]:
            #     score4 = forms.FloatField(label=f["name"], required=False)
        # if score1:
        #     self.fields['score1'] = score1
        #     self.initial['score1'] = kwargs["instance"].score1
        # if score2:
        #     self.fields['score2'] = score2
        #     self.initial['score1'] = kwargs["instance"].score1
        # if score3:
        #     self.fields['score3'] = score3
        #     self.initial['score1'] = kwargs["instance"].score1
        # if score4:
        #     self.fields['score4'] = score4
        #     self.initial['score1'] = kwargs["instance"].score1


class UserServerForm(forms.Form):
    status = forms.ChoiceField(label='学生状态', choices=((0, '全部'), (1, "正常")), required=False)

    def __init__(self, request_user, *args, **kwargs):
        super(UserServerForm, self).__init__(*args, **kwargs)
        agent_queryset = request_user.get_teacher_list("agent")
        if agent_queryset.exists():
            agent = forms.ModelChoiceField(queryset=agent_queryset, label='客服', required=False)
            self.fields["agent"] = agent
        lecturer_queryset = request_user.get_teacher_list("lecturer")
        if lecturer_queryset.exists():
            lecturer = forms.ModelChoiceField(queryset=lecturer_queryset, label='讲师', required=False)
            self.fields["lecturer"] = lecturer


class UserSectionForm(forms.Form):
    status = forms.ChoiceField(label='学生状态', choices=((0, '全部'), (1, "正常")), required=False)
    expire_date_start = forms.CharField(label='结课开始日', required=False)
    expire_date_end = forms.CharField(label='结课结束日', required=False)

    def _get_user_class_queryset(self,request_user):
        return request_user.userprofile.get_class_list()

    def __init__(self, request_user, *args, **kwargs):
        super(UserSectionForm, self).__init__(*args, **kwargs)
        mentor_queryset = request_user.get_teacher_list("mentor")
        user_class_queryset = self._get_user_class_queryset(request_user)
        if mentor_queryset.exists():
            self.fields['assistant'] = forms.ModelChoiceField(queryset=mentor_queryset, label='助教', required=False)
        if user_class_queryset.exists():
            self.fields['user_class'] = forms.ModelChoiceField(queryset=user_class_queryset, label='班级', required=False)
            # self.initial['assistant'] = kwargs["instance"].userprofile.lecturer
